==> academy-course-core-2.1.9-sources.jar: com/ptteng/academy/course/model/Task.java <==
package com.ptteng.academy.course.model;

import javax.persistence.*;
import java.io.Serializable;


@Entity
@Table(name = "task")
public class Task implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 1100707670964248576L;

    public static final Integer Lock = 1;
    public static final Integer UnLock = 2;


    //搜索接口返回值isLock
    public static final Integer  UNLOCK=0;
    public static final Integer  ISLOCK =1;
    public static final Integer  ISLOCK_PUCHASED =2;
    public static final Integer  ISLOCK_SHOWED =3;
    public static final Integer UNLOCK_MEMBER = 4;
    public static final Integer LOCK_MEMBER = 5;

    public static final Integer status_normal = 1;
    public static final Integer status_freeze = 2;

    public static final Integer video_type = 1;
    public static final Integer exercise_type = 2;// 任务_习题

    public static final Integer video_type_teaching = 1;// 任务_教学视频
    public static final Integer video_type_exercise = 2;// 任务_刷题先锋

    public static final Integer exercise_multi_select = 1;//选择题 （多选）
    public static final Integer exercise_single_select = 5; // 选择题（单选）

    public static final Integer exercise_type_fillIn = 2;//填空
    public static final Integer exercise_type_TF = 4;//判断

    public static final Integer unlearned = 1;
    public static final Integer learning = 2;
    public static final Integer learned = 3;

    public static final Integer favorite = 1;
    public static final Integer not_favorite = 2;

    public static final Integer level_hide = 0;
    public static final Integer level_showed = 1;

    public static final String level_one = "1";
    public static final String level_two = "2";
    public static final String level_three = "3";
    public static final String level_four = "4";
    public static final String level_five = "5";

    public static final Integer can_unlock_via_sharing = 1;
    public static final Integer cannot_unlock_via_sharing = 2;


    private Long id;


    private String taskName;

    private String introText;

    private String frontCoverURL;

    private String videoCoverURL;

    //排序
    private Integer sort;

    //课时
    private Long periodId;

    private String periodName;

    private Integer grade;

    private Integer gradeDept;

    //难度等级
    private String difficultyLevel;

    // 是否展示难度等级
    private Integer showLevel;

    private Long lessonId;

    private String lessonName;

    private Long subjectId;

    private String subjectName;

    private String subjectFontColour;

    // 用户在该任务的学习状态
    private Integer learningProcess = Task.unlearned;

    //上下架状态
    private Integer status = Task.status_normal;

    // 任务类型
    private Integer taskType;

    // 可否分享解锁
    private Integer shareToUnlock;

    // 习题类型
    private Integer specificType;

    // 是否解析
    private Integer isAnalysis;

    //解析内容
    private String analysisContent;

    // 是否加锁
    private Integer isLock;

    private Integer isFavorite = 2;

    private Integer studyCount = 0;

    private String rcmdContents;

    private Long createBy;

    private Long updateBy;

    private Long updateAt;

    private Long createAt;

    private Integer lessonIsLock;

    private String resourceLink;

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id")
    public Long getId() {
        return id;
    }


    public void setId(Long id) {
        this.id = id;
    }

    @Column(name = "task_name")
    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    @Column(name = "intro_text")
    public String getIntroText() {
        return introText;
    }

    public void setIntroText(String introText) {
        this.introText = introText;
    }

    @Column(name = "front_cover_url")
    public String getFrontCoverURL() {
        return frontCoverURL;
    }

    public void setFrontCoverURL(String frontCoverURL) {
        this.frontCoverURL = frontCoverURL;
    }

    @Column(name = "task_type")
    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    @Column(name = "specific_type")
    public Integer getSpecificType() {
        return specificType;
    }

    public void setSpecificType(Integer specificType) {
        this.specificType = specificType;
    }

    @Column(name = "is_analysis")
    public Integer getIsAnalysis() {
        return isAnalysis;
    }

    public void setIsAnalysis(Integer isAnalysis) {
        this.isAnalysis = isAnalysis;
    }

    @Column(name = "analysis_content")
    public String getAnalysisContent() {
        return analysisContent;
    }

    public void setAnalysisContent(String analysisContent) {
        this.analysisContent = analysisContent;
    }

    @Column(name = "is_lock")
    public Integer getIsLock() {
        return isLock;
    }

    public void setIsLock(Integer isLock) {
        this.isLock = isLock;
    }

    @Column(name = "sort")
    public Integer getSort() {
        return sort;
    }


    public void setSort(Integer sort) {
        this.sort = sort;
    }

    @Column(name = "period_id")
    public Long getPeriodId() {
        return periodId;
    }

    public void setPeriodId(Long periodId) {
        this.periodId = periodId;
    }

    @Column(name = "create_by")
    public Long getCreateBy() {
        return createBy;
    }


    public void setCreateBy(Long createBy) {
        this.createBy = createBy;
    }

    @Column(name = "update_by")
    public Long getUpdateBy() {
        return updateBy;
    }


    public void setUpdateBy(Long updateBy) {
        this.updateBy = updateBy;
    }

    @Column(name = "update_at")
    public Long getUpdateAt() {
        return updateAt;
    }


    public void setUpdateAt(Long updateAt) {
        this.updateAt = updateAt;
    }

    @Column(name = "create_at")
    public Long getCreateAt() {
        return createAt;
    }


    public void setCreateAt(Long createAt) {
        this.createAt = createAt;
    }


    @Column(name = "status")
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }


    @Column(name = "subject_id")
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    @Column(name = "lesson_id")
    public Long getLessonId() {
        return lessonId;
    }

    public void setLessonId(Long lessonId) {
        this.lessonId = lessonId;
    }

    @Transient
    public String getPeriodName() {
        return periodName;
    }

    public void setPeriodName(String periodName) {
        this.periodName = periodName;
    }

    @Transient
    public String getLessonName() {
        return lessonName;
    }

    public void setLessonName(String lessonName) {
        this.lessonName = lessonName;
    }

    @Transient
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    @Column(name = "grade")
    public Integer getGrade() {
        return grade;
    }

    public void setGrade(Integer grade) {
        this.grade = grade;
    }

    @Column(name = "grade_dept")
    public Integer getGradeDept() {
        return gradeDept;
    }

    public void setGradeDept(Integer gradeDept) {
        this.gradeDept = gradeDept;
    }

    @Column(name = "learning_process")
    public Integer getLearningProcess() {
        return learningProcess;
    }

    public void setLearningProcess(Integer learningProcess) {
        this.learningProcess = learningProcess;
    }

    @Transient
    public Integer getIsFavorite() {
        return isFavorite;
    }

    public void setIsFavorite(Integer isFavorite) {
        this.isFavorite = isFavorite;
    }

    @Column(name = "study_count")
    public Integer getStudyCount() {
        return studyCount;
    }

    public void setStudyCount(Integer studyCount) {
        this.studyCount = studyCount;
    }

    @Column(name = "share_to_unlock")
    public Integer getShareToUnlock() {
        return shareToUnlock;
    }

    public void setShareToUnlock(Integer shareToUnlock) {
        this.shareToUnlock = shareToUnlock;
    }

    @Column(name = "rcmd_contents")
    public String getRcmdContents() {
        return rcmdContents;
    }

    public void setRcmdContents(String rcmdContents) {
        this.rcmdContents = rcmdContents;
    }

    @Column(name = "difficulty_level")
    public String getDifficultyLevel() {
        return difficultyLevel;
    }

    public void setDifficultyLevel(String difficultyLevel) {
        this.difficultyLevel = difficultyLevel;
    }

    @Column(name = "show_level")
    public Integer getShowLevel() {
        return showLevel;
    }

    public void setShowLevel(Integer showLevel) {
        this.showLevel = showLevel;
    }

    @Column(name = "video_cover_url")
    public String getVideoCoverURL() {
        return videoCoverURL;
    }

    public void setVideoCoverURL(String videoCoverURL) {
        this.videoCoverURL = videoCoverURL;
    }

    @Transient
    public Integer getLessonIsLock() {
        return lessonIsLock;
    }

    public void setLessonIsLock(Integer lessonIsLock) {
        this.lessonIsLock = lessonIsLock;
    }

    @Transient
    public String getResourceLink() {
        return resourceLink;
    }

    public void setResourceLink(String resourceLink) {
        this.resourceLink = resourceLink;
    }

    @Transient
    public String getSubjectFontColour() {
        return subjectFontColour;
    }

    public void setSubjectFontColour(String subjectFontColour) {
        this.subjectFontColour = subjectFontColour;
    }
}

==> academy-course-core-2.1.10-sources.jar: com/ptteng/academy/course/model/Task.java <==
package com.ptteng.academy.course.model;

import javax.persistence.*;
import java.io.Serializable;


@Entity
@Table(name = "task")
public class Task implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 1100707670964248576L;

    public static final Integer Lock = 1;
    public static final Integer UnLock = 2;


    //搜索接口返回值isLock
    public static final Integer  UNLOCK=0;
    public static final Integer  ISLOCK =1;
    public static final Integer  ISLOCK_PUCHASED =2;
    public static final Integer  ISLOCK_SHOWED =3;
    public static final Integer UNLOCK_MEMBER = 4;
    public static final Integer LOCK_MEMBER = 5;

    public static final Integer status_normal = 1;
    public static final Integer status_freeze = 2;

    public static final Integer video_type = 1;
    public static final Integer exercise_type = 2;// 任务_习题

    public static final Integer video_type_teaching = 1;// 任务_教学视频
    public static final Integer video_type_exercise = 2;// 任务_刷题先锋

    public static final Integer exercise_multi_select = 1;//选择题 （多选）
    public static final Integer exercise_single_select = 5; // 选择题（单选）

    public static final Integer exercise_type_fillIn = 2;//填空
    public static final Integer exercise_type_TF = 4;//判断

    public static final Integer unlearned = 1;
    public static final Integer learning = 2;
    public static final Integer learned = 3;

    public static final Integer favorite = 1;
    public static final Integer not_favorite = 2;

    public static final Integer level_hide = 0;
    public static final Integer level_showed = 1;

    public static final String level_one = "1";
    public static final String level_two = "2";
    public static final String level_three = "3";
    public static final String level_four = "4";
    public static final String level_five = "5";

    public static final Integer can_unlock_via_sharing = 1;
    public static final Integer cannot_unlock_via_sharing = 2;


    private Long id;


    private String taskName;

    private String introText;

    private String frontCoverURL;

    private String videoCoverURL;

    //排序
    private Integer sort;

    //课时
    private Long periodId;

    private String periodName;

    private Integer grade;

    private Integer gradeDept;

    //难度等级
    private String difficultyLevel;

    // 是否展示难度等级
    private Integer showLevel;

    private Long lessonId;

    private String lessonName;

    private Long subjectId;

    private String subjectName;

    private String subjectFontColour;

    // 用户在该任务的学习状态
    private Integer learningProcess = Task.unlearned;

    //上下架状态
    private Integer status = Task.status_normal;

    // 任务类型
    private Integer taskType;

    // 可否分享解锁
    private Integer shareToUnlock;

    // 习题类型
    private Integer specificType;

    // 是否解析
    private Integer isAnalysis;

    //解析内容
    private String analysisContent;

    // 是否加锁
    private Integer isLock;

    private Integer isFavorite = 2;

    private Integer studyCount = 0;

    private String rcmdContents;

    /**
     * 标签
     */
    private String tag;

    /**
     * 是否限免
     */
    private Integer exemption;

    /**
     * 视频暂停时间
     */
    private String pauseTime;

    private Long createBy;

    private Long updateBy;

    private Long updateAt;

    private Long createAt;

    private Integer lessonIsLock;

    private String resourceLink;

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id")
    public Long getId() {
        return id;
    }


    public void setId(Long id) {
        this.id = id;
    }

    @Column(name = "tag")
    public String getTag() {
        return tag;
    }

    @Column(name = "exemption")
    public Integer getExemption() {
        return exemption;
    }

    @Column(name = "pause_time")
    public String getPauseTime() {
        return pauseTime;
    }

    public void setPauseTime(String pauseTime) {
        this.pauseTime = pauseTime;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public void setExemption(Integer exemption) {
        this.exemption = exemption;
    }

    @Column(name = "task_name")
    public String getTaskName() {
        return taskName;
    }

    public void setTaskName(String taskName) {
        this.taskName = taskName;
    }

    @Column(name = "intro_text")
    public String getIntroText() {
        return introText;
    }

    public void setIntroText(String introText) {
        this.introText = introText;
    }

    @Column(name = "front_cover_url")
    public String getFrontCoverURL() {
        return frontCoverURL;
    }

    public void setFrontCoverURL(String frontCoverURL) {
        this.frontCoverURL = frontCoverURL;
    }

    @Column(name = "task_type")
    public Integer getTaskType() {
        return taskType;
    }

    public void setTaskType(Integer taskType) {
        this.taskType = taskType;
    }

    @Column(name = "specific_type")
    public Integer getSpecificType() {
        return specificType;
    }

    public void setSpecificType(Integer specificType) {
        this.specificType = specificType;
    }

    @Column(name = "is_analysis")
    public Integer getIsAnalysis() {
        return isAnalysis;
    }

    public void setIsAnalysis(Integer isAnalysis) {
        this.isAnalysis = isAnalysis;
    }

    @Column(name = "analysis_content")
    public String getAnalysisContent() {
        return analysisContent;
    }

    public void setAnalysisContent(String analysisContent) {
        this.analysisContent = analysisContent;
    }

    @Column(name = "is_lock")
    public Integer getIsLock() {
        return isLock;
    }

    public void setIsLock(Integer isLock) {
        this.isLock = isLock;
    }

    @Column(name = "sort")
    public Integer getSort() {
        return sort;
    }


    public void setSort(Integer sort) {
        this.sort = sort;
    }

    @Column(name = "period_id")
    public Long getPeriodId() {
        return periodId;
    }

    public void setPeriodId(Long periodId) {
        this.periodId = periodId;
    }

    @Column(name = "create_by")
    public Long getCreateBy() {
        return createBy;
    }


    public void setCreateBy(Long createBy) {
        this.createBy = createBy;
    }

    @Column(name = "update_by")
    public Long getUpdateBy() {
        return updateBy;
    }


    public void setUpdateBy(Long updateBy) {
        this.updateBy = updateBy;
    }

    @Column(name = "update_at")
    public Long getUpdateAt() {
        return updateAt;
    }


    public void setUpdateAt(Long updateAt) {
        this.updateAt = updateAt;
    }

    @Column(name = "create_at")
    public Long getCreateAt() {
        return createAt;
    }


    public void setCreateAt(Long createAt) {
        this.createAt = createAt;
    }


    @Column(name = "status")
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }


    @Column(name = "subject_id")
    public Long getSubjectId() {
        return subjectId;
    }

    public void setSubjectId(Long subjectId) {
        this.subjectId = subjectId;
    }

    @Column(name = "lesson_id")
    public Long getLessonId() {
        return lessonId;
    }

    public void setLessonId(Long lessonId) {
        this.lessonId = lessonId;
    }

    @Transient
    public String getPeriodName() {
        return periodName;
    }

    public void setPeriodName(String periodName) {
        this.periodName = periodName;
    }

    @Transient
    public String getLessonName() {
        return lessonName;
    }

    public void setLessonName(String lessonName) {
        this.lessonName = lessonName;
    }

    @Transient
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }

    @Column(name = "grade")
    public Integer getGrade() {
        return grade;
    }

    public void setGrade(Integer grade) {
        this.grade = grade;
    }

    @Column(name = "grade_dept")
    public Integer getGradeDept() {
        return gradeDept;
    }

    public void setGradeDept(Integer gradeDept) {
        this.gradeDept = gradeDept;
    }

    @Column(name = "learning_process")
    public Integer getLearningProcess() {
        return learningProcess;
    }

    public void setLearningProcess(Integer learningProcess) {
        this.learningProcess = learningProcess;
    }

    @Transient
    public Integer getIsFavorite() {
        return isFavorite;
    }

    public void setIsFavorite(Integer isFavorite) {
        this.isFavorite = isFavorite;
    }

    @Column(name = "study_count")
    public Integer getStudyCount() {
        return studyCount;
    }

    public void setStudyCount(Integer studyCount) {
        this.studyCount = studyCount;
    }

    @Column(name = "share_to_unlock")
    public Integer getShareToUnlock() {
        return shareToUnlock;
    }

    public void setShareToUnlock(Integer shareToUnlock) {
        this.shareToUnlock = shareToUnlock;
    }

    @Column(name = "rcmd_contents")
    public String getRcmdContents() {
        return rcmdContents;
    }

    public void setRcmdContents(String rcmdContents) {
        this.rcmdContents = rcmdContents;
    }

    @Column(name = "difficulty_level")
    public String getDifficultyLevel() {
        return difficultyLevel;
    }

    public void setDifficultyLevel(String difficultyLevel) {
        this.difficultyLevel = difficultyLevel;
    }

    @Column(name = "show_level")
    public Integer getShowLevel() {
        return showLevel;
    }

    public void setShowLevel(Integer showLevel) {
        this.showLevel = showLevel;
    }

    @Column(name = "video_cover_url")
    public String getVideoCoverURL() {
        return videoCoverURL;
    }

    public void setVideoCoverURL(String videoCoverURL) {
        this.videoCoverURL = videoCoverURL;
    }

    @Transient
    public Integer getLessonIsLock() {
        return lessonIsLock;
    }

    public void setLessonIsLock(Integer lessonIsLock) {
        this.lessonIsLock = lessonIsLock;
    }

    @Transient
    public String getResourceLink() {
        return resourceLink;
    }

    public void setResourceLink(String resourceLink) {
        this.resourceLink = resourceLink;
    }

    @Transient
    public String getSubjectFontColour() {
        return subjectFontColour;
    }

    public void setSubjectFontColour(String subjectFontColour) {
        this.subjectFontColour = subjectFontColour;
    }
}
